// @ts-nocheck
import { useState, useRef } from 'react'
import { Canvas, useFrame } from '@react-three/fiber'
import { Points, PointMaterial } from '@react-three/drei'
import * as random from 'maath/random/dist/maath-random.esm'
import styled from 'styled-components'
import { SiGithub } from 'react-icons/si'
import Button from './Button'

const Galaxy = (props) => {
  const ref = useRef()
  const [sphere] = useState(() => random.inSphere(new Float32Array(5000), { radius: 1.5 }))

  useFrame((state, delta) => {
    ref.current.rotation.x -= delta / 10
    ref.current.rotation.y -= delta / 15
  })
  return (
    <group rotation={[0, 0, Math.PI / 4]}>
      <Points ref={ref} positions={sphere} stride={3} frustumCulled={false} {...props}>
        {/* <PointMaterial transparent color="#ffa0e0" size={0.005} sizeAttenuation={true} depthWrite={false} /> */}
        <PointMaterial transparent color='#0072CE' size={0.005} sizeAttenuation={true} depthWrite={false} />
      </Points>
    </group>
  )
}

export default function Banner () {
  return (
    <Wrapper>
      <Canvas camera={{ position: [0, 0, 1] }}>
        <Galaxy />
      </Canvas>
      <Overlay>
        <BannerTitle type='main' fontSize='5em'>Bankware Global</BannerTitle>
        <BannerTitle type='sub' fontSize='3.5em'>Software Lab.</BannerTitle>
        <BannerDesc>Analyzing new technologies and ideas • Developing innovative products and services</BannerDesc>
        <ButtonGroup>
          <Button text='Documetation' />
          <Button text='GitHub' icon={<SiGithub />}/>
        </ButtonGroup>
      </Overlay>
    </Wrapper>
  )
}

const Wrapper = styled.div`
    position: relative;
    width: 100%;
    height: 510px;
    background-color: #12071f;
`
const Overlay = styled.div`
    position: absolute;
    top: 50%;
    left: 50%;
    transform: translate3d(-50%,-50%,0);
    text-align: center;
`
const BannerTitle = styled.h1`
    margin: 0;
    padding: 0;
    font-size: ${(props) => props.fontSize};
    font-weight: 600;
    letter-spacing: -0.05em;
    background: ${(props) => (props.type === 'main' ? 'linear-gradient(30deg, #0072CE, #fff)' : '#fff')};
    background-clip: text;
    -webkit-text-fill-color: transparent;
`
const BannerDesc = styled.h3`
  font-size: 1.5em;
  font-weight: 400;
  margin-top: 15px;
  color: #fff;
`
const ButtonGroup = styled.div`
  display: flex;
  margin-top: 15px;
  width: 100%;
  justify-content: center;
`
